@@ -26,6 +26,7 @@ from .tcpconnection import TCPConnection
 from .mqttconnection import MQTTConnection
 from .zmqconnection import ZMQConnection
 from .dashconnection import DashConnection
+from .serialconnection import SerialConnection
 from .load_config import decode_cfg64, encode_cfg64, load_all_controls_from_config, get_control_dict_from_config, get_control_from_config
 # from .bleconnection import BLEConnection
 from .iotcontrol.enums import (
@@ -48,7 +49,8 @@ from .iotcontrol.enums import (
     GraphXAxisLabelsStyle,
     TextFormat,
     DirectionStyle,
-    ColorPickerStyle
+    ColorPickerStyle,
+    ControlName
 )
 from .iotcontrol.audio_visual_display import AudioVisualDisplay
 from .iotcontrol.graph import Graph, GraphLine
