@@ -22,5 +22,7 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 """
 CONNECTION_PUB_URL = "inproc://DASHIO_CONN_PUB_{id}"
-DEVICE_PUB_URL = "inproc://DASHIO_DVCE_PUB_{id}"
+MEMORY_REQ_URL = "inproc://DASHIO_MEM_REQ_{id}"
+TASK_PULL = "inproc://DASHIO_TASK_PULL_{id}"
+
 BAD_CHARS = {ord(i): None for i in '\t\n'}
