@@ -22,13 +22,54 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 """
 from ..constants import BAD_CHARS
-from .control import Control, ControlPosition, _get_title_position, _get_color_picker_style
+from .control import Control, ControlPosition, ControlConfig, _get_title_position, _get_color_picker_style
 from .enums import (ColorPickerStyle, TitlePosition)
 
 
+class ColorPickerConfig(ControlConfig):
+    """ColorPickerConfig"""
+    def __init__(
+        self,
+        control_id: str,
+        title: str,
+        title_position: TitlePosition,
+        style: ColorPickerStyle,
+        send_only_on_release: bool,
+        control_position: ControlPosition
+    ) -> None:
+        super().__init__(control_id, title, control_position, title_position)
+        self.cfg["style"] = style.value
+        self.cfg["sendOnlyOnRelease"] = send_only_on_release
+
+    @classmethod
+    def from_dict(cls, cfg_dict: dict):
+        """Instantiates ColorPickerConfig from cfg dictionary
+
+        Parameters
+        ----------
+        cfg_dict : dict
+            A dictionary usually loaded from a config json from IoTDashboard App
+
+        Returns
+        -------
+        ColorPickerConfig
+        """
+        tmp_cls = cls(
+            cfg_dict["controlID"],
+            cfg_dict["title"],
+            _get_title_position(cfg_dict["titlePosition"]),
+            _get_color_picker_style(cfg_dict["pickerStyle"]),
+            cfg_dict["sendOnlyOnRelease"],
+            ControlPosition(cfg_dict["xPositionRatio"], cfg_dict["yPositionRatio"], cfg_dict["widthRatio"], cfg_dict["heightRatio"])
+        )
+        tmp_cls.parent_id = cfg_dict["parentID"]
+        return tmp_cls
+
+
 class ColorPicker(Control):
     """Color Picker Control
     """
+
     def __init__(
         self,
         control_id: str,
@@ -56,12 +97,19 @@ class ColorPicker(Control):
             send only on release, by default True
 
         """
-        super().__init__("CLR", control_id, title=title, control_position=control_position, title_position=title_position)
-        self.picker_style = style
-        self.send_only_on_release = send_only_on_release
+        super().__init__("CLR", control_id)
+        self._cfg_columnar.append(
+            ColorPickerConfig(
+                control_id,
+                title,
+                title_position,
+                style,
+                send_only_on_release,
+                control_position
+            )
+        )
         self._color_value = "#4F5GA2"
 
-
     @classmethod
     def from_cfg_dict(cls, cfg_dict: dict):
         """Instatiates ColorPicker from cfg dictionary
@@ -86,24 +134,20 @@ class ColorPicker(Control):
         tmp_cls.parent_id = cfg_dict["parentID"]
         return tmp_cls
 
-
     def get_state(self):
         return self._control_hdr_str + f"{self._color_value}\n"
 
-
     def send_color_rgb(self, red: int, green: int, blue: int):
         """Send color as #rrggbb for the given color values."""
         self._color_value = f"#{red:02x}{green:02x}{blue:02x}"
         self.state_str = self._control_hdr_str + f"{self._color_value}\n"
 
-
-    def color_to_rgb(self, color_value:str) -> tuple:
+    def color_to_rgb(self, color_value: str) -> tuple:
         """Return (red, green, blue) for the color_value."""
         clr = color_value.lstrip('#')
         len_v = len(clr)
         return tuple(int(clr[i:i + len_v // 3], 16) for i in range(0, len_v, len_v // 3))
 
-
     @property
     def color_value(self) -> str:
         """Color value
@@ -120,36 +164,3 @@ class ColorPicker(Control):
         _val = val.translate(BAD_CHARS)
         self._color_value = _val
         self.state_str = self._control_hdr_str + f"{_val}\n"
-
-
-    @property
-    def style(self) -> ColorPickerStyle:
-        """Color Picker style
-
-        Returns
-        -------
-        ColorPickerStyle
-            Style to use for the color picker control
-        """
-        return self._style
-
-    @style.setter
-    def style(self, val: ColorPickerStyle):
-        self._style = val
-        self._cfg["style"] = val.value
-
-
-    @property
-    def send_only_on_release(self) -> bool:
-        """Send color on release
-
-        Returns
-        -------
-        bool
-            Set to false for data firehose
-        """
-        return self._cfg["sendOnlyOnRelease"]
-
-    @send_only_on_release.setter
-    def send_only_on_release(self, val: bool):
-        self._cfg["sendOnlyOnRelease"] = val
