@@ -22,9 +22,10 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 """
 from ..constants import BAD_CHARS
-from .control import Control, ControlPosition, _get_title_position, _get_graph_x_axis_labels_style
+from .control import Control, ControlPosition, ControlConfig, _get_title_position, _get_graph_x_axis_labels_style
 from .enums import Color, GraphLineType, GraphXAxisLabelsStyle, TitlePosition
 
+
 class GraphLine:
     """GraphLine class
     """
@@ -48,6 +49,67 @@ class GraphLine:
         return data_str
 
 
+class GraphConfig(ControlConfig):
+    """GraphConfig"""
+    def __init__(
+        self,
+        control_id,
+        title: str,
+        title_position: TitlePosition,
+        x_axis_label: str,
+        x_axis_min: float,
+        x_axis_max: float,
+        x_axis_num_bars: int,
+        x_axis_labels_style: GraphXAxisLabelsStyle,
+        y_axis_label: str,
+        y_axis_min: float,
+        y_axis_max: float,
+        y_axis_num_bars: int,
+        control_position: ControlPosition,
+    ) -> None:
+        super().__init__(control_id, title, control_position, title_position)
+        self.cfg["xAxisLabel"] = x_axis_label.translate(BAD_CHARS)
+        self.cfg["xAxisMin"] = x_axis_min
+        self.cfg["xAxisMax"] = x_axis_max
+        self.cfg["xAxisNumBars"] = x_axis_num_bars
+        self.cfg["xAxisLabelsStyle"] = x_axis_labels_style.value
+        self.cfg["yAxisLabel"] = y_axis_label.translate(BAD_CHARS)
+        self.cfg["yAxisMin"] = y_axis_min
+        self.cfg["yAxisMax"] = y_axis_max
+        self.cfg["yAxisNumBars"] = y_axis_num_bars
+
+    @classmethod
+    def from_dict(cls, cfg_dict: dict):
+        """Instantiates GraphConfig from cfg dictionary
+
+        Parameters
+        ----------
+        cfg_dict : dict
+            A dictionary usually loaded from a config json from IoTDashboard App
+
+        Returns
+        -------
+        GraphConfig
+        """
+        tmp_cls = cls(
+            cfg_dict["controlID"],
+            cfg_dict["title"],
+            _get_title_position(cfg_dict["titlePosition"]),
+            cfg_dict["xAxisLabel"],
+            cfg_dict["xAxisMin"],
+            cfg_dict["xAxisMax"],
+            cfg_dict["xAxisNumBars"],
+            _get_graph_x_axis_labels_style(cfg_dict["xAxisLabelsStyle"]),
+            cfg_dict["yAxisLabel"],
+            cfg_dict["yAxisMin"],
+            cfg_dict["yAxisMax"],
+            cfg_dict["yAxisNumBars"],
+            ControlPosition(cfg_dict["xPositionRatio"], cfg_dict["yPositionRatio"], cfg_dict["widthRatio"], cfg_dict["heightRatio"])
+        )
+        tmp_cls.parent_id = cfg_dict["parentID"]
+        return tmp_cls
+
+
 class Graph(Control):
     """A Graph control
 
@@ -56,6 +118,7 @@ class Graph(Control):
     Control :
         The control base class
     """
+
     def get_state(self):
         """Called by iotdashboard"""
         state_str = ""
@@ -110,18 +173,61 @@ class Graph(Control):
         control_position : ControlPosition, optional
             The position of the control on a DeviceView, by default None
         """
-        super().__init__("GRPH", control_id, title=title, control_position=control_position, title_position=title_position)
-        self.x_axis_label = x_axis_label
-        self.x_axis_min = x_axis_min
-        self.x_axis_max = x_axis_max
-        self.x_axis_num_bars = x_axis_num_bars
-        self.x_axis_labels_style = x_axis_labels_style
-        self.y_axis_label = y_axis_label
-        self.y_axis_min = y_axis_min
-        self.y_axis_max = y_axis_max
-        self.y_axis_num_bars = y_axis_num_bars
-
+        super().__init__("GRPH", control_id)
+        self._cfg_columnar.append(
+            GraphConfig(
+                control_id,
+                title,
+                title_position,
+                x_axis_label,
+                x_axis_min,
+                x_axis_max,
+                x_axis_num_bars,
+                x_axis_labels_style,
+                y_axis_label,
+                y_axis_min,
+                y_axis_max,
+                y_axis_num_bars,
+                control_position
+            )
+        )
         self.line_dict = {}
+        self._x_axis_min = x_axis_min
+        self._x_axis_max = x_axis_max
+        self._x_axis_num_bars = x_axis_num_bars
+        self._y_axis_min = y_axis_min
+        self._y_axis_max = y_axis_max
+        self._y_axis_num_bars = y_axis_num_bars
+
+    @property
+    def x_axis_min(self):
+        """Returns the X axis minimum value"""
+        return self._x_axis_min
+
+    @property
+    def x_axis_max(self):
+        """Returns the X axis maximum value"""
+        return self._x_axis_max
+
+    @property
+    def x_axis_num_bars(self):
+        """Returns the x axis number of bars"""
+        return self._x_axis_num_bars
+
+    @property
+    def y_axis_min(self):
+        """Returns the Y axis minimum value"""
+        return self._y_axis_min
+
+    @property
+    def y_axis_max(self):
+        """Returns the Y axis maximum value"""
+        return self._y_axis_max
+
+    @property
+    def y_axis_num_bars(self):
+        """Returns the y axis number of bars"""
+        return self.y_axis_num_bars
 
     @classmethod
     def from_cfg_dict(cls, cfg_dict: dict):
@@ -173,139 +279,3 @@ class Graph(Control):
         for key, line in self.line_dict.items():
             state_str += self._control_hdr_str + key + line.get_line_data()
         self.state_str = state_str
-
-    @property
-    def x_axis_label(self) -> str:
-        """Returns the x_axis_label string.
-
-        Returns
-        -------
-        str
-            The x_axis_label
-        """
-        return self._cfg["xAxisLabel"]
-
-    @x_axis_label.setter
-    def x_axis_label(self, val: str):
-        self._cfg["xAxisLabel"] = val.translate(BAD_CHARS)
-
-    @property
-    def x_axis_min(self) -> float:
-        """Returns the x_axis_min
-
-        Returns
-        -------
-        float
-            The x_axis_min
-        """
-        return self._cfg["xAxisMin"]
-
-    @x_axis_min.setter
-    def x_axis_min(self, val: float):
-        self._cfg["xAxisMin"] = val
-
-    @property
-    def x_axis_max(self) -> float:
-        """Returns the x_axis_max
-
-        Returns
-        -------
-        float
-            The x_axis_max
-        """
-        return self._cfg["xAxisMax"]
-
-    @x_axis_max.setter
-    def x_axis_max(self, val: float):
-        self._cfg["xAxisMax"] = val
-
-    @property
-    def x_axis_num_bars(self) -> int:
-        """Returns the x_axis_num_bars
-
-        Returns
-        -------
-        int
-            The x_axis_num_bars
-        """
-        return self._cfg["xAxisNumBars"]
-
-    @x_axis_num_bars.setter
-    def x_axis_num_bars(self, val: int):
-        self._cfg["xAxisNumBars"] = val
-
-    @property
-    def x_axis_labels_style(self) -> GraphXAxisLabelsStyle:
-        """Returns the x_axis_labels_style
-
-        Returns
-        -------
-        GraphXAxisLabelsStyle
-            The x_axis_labels_style
-        """
-        return self._x_axis_labels_style
-
-    @x_axis_labels_style.setter
-    def x_axis_labels_style(self, val: GraphXAxisLabelsStyle):
-        self._x_axis_labels_style = val
-        self._cfg["xAxisLabelsStyle"] = val.value
-
-    @property
-    def y_axis_label(self) -> str:
-        """Returns the y_axis_label
-
-        Returns
-        -------
-        str
-            The y_axis_label
-        """
-        return self._cfg["yAxisLabel"]
-
-    @y_axis_label.setter
-    def y_axis_label(self, val: str):
-        self._cfg["yAxisLabel"] = val.translate(BAD_CHARS)
-
-    @property
-    def y_axis_min(self) -> float:
-        """Returns the y_axis_min
-
-        Returns
-        -------
-        float
-            The y_axis_min
-        """
-        return self._cfg["yAxisMin"]
-
-    @y_axis_min.setter
-    def y_axis_min(self, val: float):
-        self._cfg["yAxisMin"] = val
-
-    @property
-    def y_axis_max(self) -> float:
-        """Returns the y_axis_max
-
-        Returns
-        -------
-        float
-            The y_axis_max
-        """
-        return self._cfg["yAxisMax"]
-
-    @y_axis_max.setter
-    def y_axis_max(self, val: float):
-        self._cfg["yAxisMax"] = val
-
-    @property
-    def y_axis_num_bars(self) -> int:
-        """Returns the y_axis_num_bars
-
-        Returns
-        -------
-        int
-            The y_axis_num_bars
-        """
-        return self._cfg["yAxisNumBars"]
-
-    @y_axis_num_bars.setter
-    def y_axis_num_bars(self, val: int):
-        self._cfg["yAxisNumBars"] = val
