@@ -26,7 +26,7 @@ import dateutil
 import json
 
 from ..constants import BAD_CHARS
-from .control import Control, ControlPosition, _get_title_position
+from .control import Control, ControlPosition, ControlConfig, _get_title_position
 from .enums import TitlePosition, Color
 
 
@@ -89,6 +89,7 @@ class MapLocation:
         """
         return f"\t{self.latitude},{self.longitude}\n"
 
+
 class MapTrack:
     """A Map track
     """
@@ -139,11 +140,13 @@ class Map(Control):
     """A Map control
     """
 
-    def __init__(self,
-                 control_id,
-                 title="A Map",
-                 title_position=TitlePosition.BOTTOM,
-                 control_position=None):
+    def __init__(
+        self,
+        control_id,
+        title="A Map",
+        title_position=TitlePosition.BOTTOM,
+        control_position=None
+    ):
         """A Map control
 
         Parameters
@@ -157,7 +160,8 @@ class Map(Control):
         title_position : TitlePosition, optional
             Position of the title when displayed on the iotdashboard app, by default None
         """
-        super().__init__("MAP", control_id, title=title, control_position=control_position, title_position=title_position)
+        super().__init__("MAP", control_id)
+        self._cfg_columnar.append(ControlConfig(control_id, title, control_position, title_position))
         self.tracks = {}
         self.tracks["DEFAULT"] = self.default_track
         self.message_rx_event = self._get_tracks_from_timestamp
@@ -194,7 +198,7 @@ class Map(Control):
         if self.tracks:
             for _, value in self.tracks:
                 if value.track_start_time > from_timestamp:
-                    reply =+ self._control_hdr_str + dashboard_id + value.get_track() + "\n"
+                    reply = + self._control_hdr_str + dashboard_id + value.get_track() + "\n"
         return reply
 
     def add_location_to_track(self, location: MapLocation, track_id: str) -> None:
